@@ -10,9 +10,9 @@ from svtplay_dl.utils.stream import sort_quality
 class streamTest_sort(unittest.TestCase):
     def test_sort(self):
         data = [
-            DASH(setup_defaults(), "http://example.com", 3000),
-            HLS(setup_defaults(), "http://example.com", 2000),
-            HTTP(setup_defaults(), "http://example.com", 3001),
+            DASH(setup_defaults(), "http://example.com", 3000, None),
+            HLS(setup_defaults(), "http://example.com", 2000, None),
+            HTTP(setup_defaults(), "http://example.com", 3001, None),
         ]
         assert all(
             [
@@ -20,9 +20,9 @@ class streamTest_sort(unittest.TestCase):
                 for a, b in zip(
                     sort_quality(data),
                     [
-                        HTTP(setup_defaults(), "http://example.com", 3001),
-                        DASH(setup_defaults(), "http://example.com", 3000),
-                        HLS(setup_defaults(), "http://example.com", 2000),
+                        HTTP(setup_defaults(), "http://example.com", 3001, None),
+                        DASH(setup_defaults(), "http://example.com", 3000, None),
+                        HLS(setup_defaults(), "http://example.com", 2000, None),
                     ],
                 )
             ]
